@@ -11,14 +11,23 @@ class RetinaClient:
 
     def detect(self, frame):
         img = vision.encode_img(frame)
+        y, x, _ = frame.shape
         data = {"image": img}
         results = requests.post(self.host, json=data)
 
         res = []
         for result in results.json():
             if float(result["confidence"]) >= self.confidence:
-                res.append(result)
-
+                r = result
+                if r["point"]["x1"] < 0:
+                    r["point"]["x1"] = 0
+                if r["point"]["x2"] >= x:
+                    r["point"]["x2"] = x-1
+                if r["point"]["y1"] < 0:
+                    r["point"]["y1"] = 0
+                if r["point"]["y2"] >= y:
+                    r["point"]["y2"] = y-1
+                res.append(r)
         return res
 
     def write_bbox(self, frame, results, confidence=True, landmark=True, vis_thresh=0.6):
